==> calligra_2.9.7.orig.tar.xz: calligra-2.9.7/stage/plugins/pageeffects/clockwipe/doublesweepwipe/KPrDoubleSweepWipeEffectFactory.h <==
/* This file is part of the KDE project
   Copyright (C) 2008 Sven Langkamp <sven.langkamp@gmail.com>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPRDOUBLESWEEPWIPEEFFECTFACTORY_H
#define KPRDOUBLESWEEPWIPEEFFECTFACTORY_H

#include <KPrPageEffectFactory.h>

class KPrDoubleSweepWipeEffectFactory : public KPrPageEffectFactory
{
public:
    KPrDoubleSweepWipeEffectFactory();
    virtual ~KPrDoubleSweepWipeEffectFactory();
    virtual QString subTypeName(int subType) const;

    enum SubType {
        ParallelVertical,
        ParallelDiagonal,
        OppositeVertical,
        OppositeHorizontal,
        ParallelDiagonalTopLeft,
        ParallelDiagonalBottomLeft,
        ParallelVerticalReverse,
        ParallelDiagonalReverse,
        OppositeVerticalReverse,
        OppositeHorizontalReverse,
        ParallelDiagonalTopLeftReverse,
        ParallelDiagonalBottomLeftReverse
    };
};

#endif /* KPRDOUBLESWEEPWIPEEFFECTFACTORY_H */

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/plugins/pageeffects/clockwipe/doublesweepwipe/KPrDoubleSweepWipeEffectFactory.h <==
/* This file is part of the KDE project
   Copyright (C) 2008 Sven Langkamp <sven.langkamp@gmail.com>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPRDOUBLESWEEPWIPEEFFECTFACTORY_H
#define KPRDOUBLESWEEPWIPEEFFECTFACTORY_H

#include <KPrPageEffectFactory.h>

class KPrDoubleSweepWipeEffectFactory : public KPrPageEffectFactory
{
public:
    KPrDoubleSweepWipeEffectFactory();
    ~KPrDoubleSweepWipeEffectFactory() override;
    QString subTypeName(int subType) const override;

    enum SubType {
        ParallelVertical,
        ParallelDiagonal,
        OppositeVertical,
        OppositeHorizontal,
        ParallelDiagonalTopLeft,
        ParallelDiagonalBottomLeft,
        ParallelVerticalReverse,
        ParallelDiagonalReverse,
        OppositeVerticalReverse,
        OppositeHorizontalReverse,
        ParallelDiagonalTopLeftReverse,
        ParallelDiagonalBottomLeftReverse
    };
};

#endif /* KPRDOUBLESWEEPWIPEEFFECTFACTORY_H */
